@@ -1,7 +1,6 @@
 package Acme::Opish;
 
-use vars qw($VERSION);
-$VERSION = '0.03.1';
+use vars qw($VERSION); $VERSION = '0.05.1';
 use base qw(Exporter);
 use vars qw(@EXPORT @EXPORT_OK);
 @EXPORT = @EXPORT_OK = qw(
@@ -49,6 +48,7 @@ my %OK; @OK{qw(
     Psyche
     psyche
     Quixote
+    recipie
     Sade
     Salome
     saute
@@ -216,11 +216,6 @@ Acme::Opish - Prefix the audible vowels of words
   print enop(-opish_prefix => 'ubb', 'Foo bar?');
   # Fubboo bubbar?
 
-=head1 ABSTRACT
-
-Add an arbitrary prefix to the vowel groups of words, except for the 
-"silent e" and "starting, non-vowel y's".
-
 =head1 DESCRIPTION
 
 Convert words to Opish, which is similar to "Ubish", but infinitely 
@@ -261,14 +256,14 @@ place of "op".
 Add the given arguments to the list of words that are to be 
 converted without regard for the "silent e".
 
-This function returns the number of keys in the "not silent e" list.
+This function returns the keys in the "not silent e" list.
 
 =head2 has_silent_e ARRAY
 
 Delete the given arguments from the list of words that are to be
 converted with regard for the "silent e".
 
-This function returns the number of keys in the "not silent e" list.
+This function returns the keys in the "not silent e" list.
 
 =head1 SEE ALSO
 
@@ -290,7 +285,7 @@ Hopellopo Opaeropyk!
 
 =head1 AUTHOR
 
-Gopene Bopoggs, E<lt>cpan@ology.netE<gt>
+Gopene Bopoggs, E<lt>gene@cpan.org<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
